==> apache-camel-quarkus-2.7.1-src.zip: camel-quarkus-2.7.1/extensions-core/core/runtime/src/main/java/org/apache/camel/quarkus/core/StaticAnnotationTypeConverterLoader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.core;

import java.util.Set;

import org.apache.camel.impl.converter.AnnotationTypeConverterLoader;
import org.apache.camel.spi.TypeConverterRegistry;

public class StaticAnnotationTypeConverterLoader extends AnnotationTypeConverterLoader {

    private static StaticAnnotationTypeConverterLoader INSTANCE = new StaticAnnotationTypeConverterLoader();

    public static StaticAnnotationTypeConverterLoader getInstance() {
        return INSTANCE;
    }

    private StaticAnnotationTypeConverterLoader() {
        //loader skips discovery, PackageScanClassResolver is not used
        super(null);
    }

    public void load(TypeConverterRegistry registry, Set<Class> converterClasses) {
        for (Class clazz : converterClasses) {
            loadConverterMethods(registry, clazz);
        }
    }
}

==> apache-camel-quarkus-3.27.2-src.zip: camel-quarkus-3.27.2/extensions-core/core/runtime/src/main/java/org/apache/camel/quarkus/core/StaticAnnotationTypeConverterLoader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.core;

import java.util.Set;

import org.apache.camel.impl.converter.AnnotationTypeConverterLoader;
import org.apache.camel.spi.TypeConverterRegistry;

public class StaticAnnotationTypeConverterLoader extends AnnotationTypeConverterLoader {

    private static StaticAnnotationTypeConverterLoader INSTANCE = new StaticAnnotationTypeConverterLoader();

    public static StaticAnnotationTypeConverterLoader getInstance() {
        return INSTANCE;
    }

    private StaticAnnotationTypeConverterLoader() {
        //loader skips discovery, PackageScanClassResolver is not used
        super(null);
    }

    public void load(TypeConverterRegistry registry, Set<Class<?>> converterClasses) {
        for (Class<?> clazz : converterClasses) {
            loadConverterMethods(registry, clazz);
        }
    }
}
